# AWS Amplify Lints

Lints used throughout Flutter packages and plugins.

## Lints

The linter rules in this package are derived from the Dart team's [lints](https://pub.dev/packages/lints) package (for Dart packages) and [flutter_lints](https://pub.dev/packages/flutter_lints) (for Flutter apps/plugins/packages). A link to the description for each of the additional linter rules is provided below. More detail about linter rules can be found on the official linter rules [homepage](https://dart.dev/tools/linter-rules).

### Dart/Flutter Libraries ([`library.yaml`](lib/library.yaml))

Libraries will use the `package:lints` "recommended" ruleset plus the following:

- [always_declare_return_types](https://dart.dev/tools/linter-rules#always_declare_return_types)
- [always_use_package_imports](https://dart.dev/tools/linter-rules#always_use_package_imports)
- [avoid_catches_without_on_clauses](https://dart.dev/tools/linter-rules#avoid_catches_without_on_clauses)
- [avoid_classes_with_only_static_members](https://dart.dev/tools/linter-rules#avoid_classes_with_only_static_members)
- [avoid_dynamic_calls](https://dart.dev/tools/linter-rules#avoid_dynamic_calls)
- [avoid_equals_and_hash_code_on_mutable_classes](https://dart.dev/tools/linter-rules#avoid_equals_and_hash_code_on_mutable_classes)
- [avoid_field_initializers_in_const_classes](https://dart.dev/tools/linter-rules#avoid_field_initializers_in_const_classes)
- [avoid_js_rounded_ints](https://dart.dev/tools/linter-rules#avoid_js_rounded_ints)
- [avoid_multiple_declarations_per_line](https://dart.dev/tools/linter-rules#avoid_multiple_declarations_per_line)
- [avoid_positional_boolean_parameters](https://dart.dev/tools/linter-rules#avoid_positional_boolean_parameters)
- [avoid_print](https://dart.dev/tools/linter-rules#avoid_print)
- [avoid_type_to_string](https://dart.dev/tools/linter-rules#avoid_type_to_string)
- [avoid_unnecessary_containers](https://dart.dev/tools/linter-rules#avoid_unnecessary_containers)
- [avoid_unused_constructor_parameters](https://dart.dev/tools/linter-rules#avoid_unused_constructor_parameters)
- [avoid_void_async](https://dart.dev/tools/linter-rules#avoid_void_async)
- [cancel_subscriptions](https://dart.dev/tools/linter-rules#cancel_subscriptions)
- [cascade_invocations](https://dart.dev/tools/linter-rules#cascade_invocations)
- [close_sinks](https://dart.dev/tools/linter-rules#close_sinks)
- [comment_references](https://dart.dev/tools/linter-rules#comment_references)
- [conditional_uri_does_not_exist](https://dart.dev/tools/linter-rules#conditional_uri_does_not_exist)
- [depend_on_referenced_packages](https://dart.dev/tools/linter-rules#depend_on_referenced_packages)
- [deprecated_consistency](https://dart.dev/tools/linter-rules#deprecated_consistency)
- [diagnostic_describe_all_properties](https://dart.dev/tools/linter-rules#diagnostic_describe_all_properties)
- [directives_ordering](https://dart.dev/tools/linter-rules#directives_ordering)
- [eol_at_end_of_file](https://dart.dev/tools/linter-rules#eol_at_end_of_file)
- [flutter_style_todos](https://dart.dev/tools/linter-rules#flutter_style_todos)
- [join_return_with_assignment](https://dart.dev/tools/linter-rules#join_return_with_assignment)
- [lines_longer_than_80_chars](https://dart.dev/tools/linter-rules#lines_longer_than_80_chars)
- [missing_whitespace_between_adjacent_strings](https://dart.dev/tools/linter-rules#missing_whitespace_between_adjacent_strings)
- [no_runtimeType_toString](https://dart.dev/tools/linter-rules#no_runtimeType_toString)
- [noop_primitive_operations](https://dart.dev/tools/linter-rules#noop_primitive_operations)
- [omit_local_variable_types](https://dart.dev/tools/linter-rules#omit_local_variable_types)
- [only_throw_errors](https://dart.dev/tools/linter-rules#only_throw_errors)
- [package_api_docs](https://dart.dev/tools/linter-rules#package_api_docs)
- [prefer_asserts_in_initializer_lists](https://dart.dev/tools/linter-rules#prefer_asserts_in_initializer_lists)
- [prefer_asserts_with_message](https://dart.dev/tools/linter-rules#prefer_asserts_with_message)
- [prefer_const_constructors](https://dart.dev/tools/linter-rules#prefer_const_constructors)
- [prefer_const_constructors_in_immutables](https://dart.dev/tools/linter-rules#prefer_const_constructors_in_immutables)
- [prefer_const_declarations](https://dart.dev/tools/linter-rules#prefer_const_declarations)
- [prefer_const_literals_to_create_immutables](https://dart.dev/tools/linter-rules#prefer_const_literals_to_create_immutables)
- [prefer_final_in_for_each](https://dart.dev/tools/linter-rules#prefer_final_in_for_each)
- [prefer_final_locals](https://dart.dev/tools/linter-rules#prefer_final_locals)
- [prefer_if_elements_to_conditional_expressions](https://dart.dev/tools/linter-rules#prefer_if_elements_to_conditional_expressions)
- [prefer_int_literals](https://dart.dev/tools/linter-rules#prefer_int_literals)
- [prefer_null_aware_method_calls](https://dart.dev/tools/linter-rules#prefer_null_aware_method_calls)
- [prefer_single_quotes](https://dart.dev/tools/linter-rules#prefer_single_quotes)
- [public_member_api_docs](https://dart.dev/tools/linter-rules#public_member_api_docs)
- [require_trailing_commas](https://dart.dev/tools/linter-rules#require_trailing_commas)
- [sized_box_for_whitespace](https://dart.dev/tools/linter-rules#sized_box_for_whitespace)
- [sort_child_properties_last](https://dart.dev/tools/linter-rules#sort_child_properties_last)
- [sort_constructors_first](https://dart.dev/tools/linter-rules#sort_constructors_first)
- [sort_unnamed_constructors_first](https://dart.dev/tools/linter-rules#sort_unnamed_constructors_first)
- [sort_pub_dependencies](https://dart.dev/tools/linter-rules#sort_pub_dependencies)
- [tighten_type_of_initializing_formals](https://dart.dev/tools/linter-rules#tighten_type_of_initializing_formals)
- [type_annotate_public_apis](https://dart.dev/tools/linter-rules#type_annotate_public_apis)
- [unawaited_futures](https://dart.dev/tools/linter-rules#unawaited_futures)
- [unnecessary_null_checks](https://dart.dev/tools/linter-rules#unnecessary_null_checks)
- [use_enums](https://dart.dev/tools/linter-rules#use_enums)
- [use_if_null_to_convert_nulls_to_bools](https://dart.dev/tools/linter-rules#use_if_null_to_convert_nulls_to_bools)
- [use_late_for_private_fields_and_variables](https://dart.dev/tools/linter-rules#use_late_for_private_fields_and_variables)
- [use_named_constants](https://dart.dev/tools/linter-rules#use_named_constants)
- [use_raw_strings](https://dart.dev/tools/linter-rules#use_raw_strings)
- [use_setters_to_change_properties](https://dart.dev/tools/linter-rules#use_setters_to_change_properties)
- [use_string_buffers](https://dart.dev/tools/linter-rules#use_string_buffers)
- [use_super_parameters](https://dart.dev/tools/linter-rules#use_super_parameters)
- [use_test_throws_matchers](https://dart.dev/tools/linter-rules#use_test_throws_matchers)
- [use_to_and_as_if_applicable](https://dart.dev/tools/linter-rules#use_to_and_as_if_applicable)
- [unnecessary_await_in_return](https://dart.dev/tools/linter-rules#unnecessary_await_in_return)
- [unnecessary_lambdas](https://dart.dev/tools/linter-rules#unnecessary_lambdas)
- [use_full_hex_values_for_flutter_colors](https://dart.dev/tools/linter-rules#use_full_hex_values_for_flutter_colors)
- [use_key_in_widget_constructors](https://dart.dev/tools/linter-rules#use_key_in_widget_constructors)


### Dart/Flutter Apps ([`app.yaml`](lib/app.yaml))

Dart and Flutter apps will use the `flutter_lints` package plus a subset of the linter rules above, namely:

- [avoid_catches_without_on_clauses](https://dart.dev/tools/linter-rules#avoid_catches_without_on_clauses)               
- [avoid_catching_errors](https://dart.dev/tools/linter-rules#avoid_catching_errors)                          
- [avoid_dynamic_calls](https://dart.dev/tools/linter-rules#avoid_dynamic_calls)                            
- [avoid_field_initializers_in_const_classes](https://dart.dev/tools/linter-rules#avoid_field_initializers_in_const_classes)      
- [cancel_subscriptions](https://dart.dev/tools/linter-rules#cancel_subscriptions)                           
- [close_sinks](https://dart.dev/tools/linter-rules#close_sinks)                                    
- [directives_ordering](https://dart.dev/tools/linter-rules#directives_ordering)                            
- [eol_at_end_of_file](https://dart.dev/tools/linter-rules#eol_at_end_of_file)                             
- [flutter_style_todos](https://dart.dev/tools/linter-rules#flutter_style_todos)                            
- [omit_local_variable_types](https://dart.dev/tools/linter-rules#omit_local_variable_types)                      
- [only_throw_errors](https://dart.dev/tools/linter-rules#only_throw_errors)                              
- [prefer_final_in_for_each](https://dart.dev/tools/linter-rules#prefer_final_in_for_each)                       
- [prefer_final_locals](https://dart.dev/tools/linter-rules#prefer_final_locals)                            
- [prefer_if_elements_to_conditional_expressions](https://dart.dev/tools/linter-rules#prefer_if_elements_to_conditional_expressions)  
- [prefer_int_literals](https://dart.dev/tools/linter-rules#prefer_int_literals)                            
- [prefer_null_aware_method_calls](https://dart.dev/tools/linter-rules#prefer_null_aware_method_calls)                 
- [prefer_single_quotes](https://dart.dev/tools/linter-rules#prefer_single_quotes)                           
- [require_trailing_commas](https://dart.dev/tools/linter-rules#require_trailing_commas)                        
- [secure_pubspec_urls](https://dart.dev/tools/linter-rules#secure_pubspec_urls)                            
- [sized_box_shrink_expand](https://dart.dev/tools/linter-rules#sized_box_shrink_expand)                        
- [sort_constructors_first](https://dart.dev/tools/linter-rules#sort_constructors_first)                        
- [sort_pub_dependencies](https://dart.dev/tools/linter-rules#sort_pub_dependencies)                          
- [tighten_type_of_initializing_formals](https://dart.dev/tools/linter-rules#tighten_type_of_initializing_formals)           
- [unawaited_futures](https://dart.dev/tools/linter-rules#unawaited_futures)                              
- [unnecessary_await_in_return](https://dart.dev/tools/linter-rules#unnecessary_await_in_return)                    
- [unnecessary_lambdas](https://dart.dev/tools/linter-rules#unnecessary_lambdas)                            
- [unnecessary_null_checks](https://dart.dev/tools/linter-rules#unnecessary_null_checks)                        
- [use_colored_box](https://dart.dev/tools/linter-rules#use_colored_box)                                
- [use_decorated_box](https://dart.dev/tools/linter-rules#use_decorated_box)                              
- [use_enums](https://dart.dev/tools/linter-rules#use_enums)                                      
- [use_if_null_to_convert_nulls_to_bools](https://dart.dev/tools/linter-rules#use_if_null_to_convert_nulls_to_bools)          
- [use_late_for_private_fields_and_variables](https://dart.dev/tools/linter-rules#use_late_for_private_fields_and_variables)      
- [use_named_constants](https://dart.dev/tools/linter-rules#use_named_constants)                            
- [use_raw_strings](https://dart.dev/tools/linter-rules#use_raw_strings)                                
- [use_setters_to_change_properties](https://dart.dev/tools/linter-rules#use_setters_to_change_properties)               
- [use_super_parameters](https://dart.dev/tools/linter-rules#use_super_parameters)                           
- [use_test_throws_matchers](https://dart.dev/tools/linter-rules#use_test_throws_matchers)                       
